AppTargeting

Struct AppTargeting 

pub struct AppTargeting {
    pub mobile_app_category_targeting: Option<NumericTargetingDimension>,
    pub mobile_app_targeting: Option<StringTargetingDimension>,
}
A subset of app inventory to target. Bid requests that match criteria in at least one of the specified dimensions will be sent.

This type is not used in any activity, and only used as part of another schema.

Fields

mobile_app_category_targeting: Option<NumericTargetingDimension>

Lists of included and excluded mobile app categories as defined in https://developers.google.com/adwords/api/docs/appendix/mobileappcategories.csv.

mobile_app_targeting: Option<StringTargetingDimension>

Targeted app IDs. App IDs can refer to those found in an app store or ones that are not published in an app store. A maximum of 30,000 app IDs can be targeted.