pub struct Image {
pub height: Option<i32>,
pub url: Option<String>,
pub width: Option<i32>,
}Expand description
An image resource. You may provide a larger image than was requested, so long as the aspect ratio is preserved.
This type is not used in any activity, and only used as part of another schema.
Fields
height: Option<i32>Image height in pixels.
url: Option<String>The URL of the image.
width: Option<i32>Image width in pixels.