pub struct NativeContent {Show 13 fields
pub advertiser_name: Option<String>,
pub app_icon: Option<Image>,
pub body: Option<String>,
pub call_to_action: Option<String>,
pub click_link_url: Option<String>,
pub click_tracking_url: Option<String>,
pub headline: Option<String>,
pub image: Option<Image>,
pub logo: Option<Image>,
pub price_display_text: Option<String>,
pub star_rating: Option<f64>,
pub video_url: Option<String>,
pub video_vast_xml: Option<String>,
}Expand description
Native content for a creative.
This type is not used in any activity, and only used as part of another schema.
Fields
advertiser_name: Option<String>The name of the advertiser or sponsor, to be displayed in the ad creative.
app_icon: Option<Image>The app icon, for app download ads.
body: Option<String>A long description of the ad.
call_to_action: Option<String>A label for the button that the user is supposed to click.
click_link_url: Option<String>The URL that the browser/SDK will load when the user clicks the ad.
click_tracking_url: Option<String>The URL to use for click tracking.
headline: Option<String>A short title for the ad.
image: Option<Image>A large image.
logo: Option<Image>A smaller image, for the advertiser’s logo.
price_display_text: Option<String>The price of the promoted app including currency info.
star_rating: Option<f64>The app rating in the app store. Must be in the range [0-5].
video_url: Option<String>The URL to fetch a native video ad.
video_vast_xml: Option<String>The contents of a VAST document for a native video ad.