pub struct PolicyTopicEntry {
pub evidences: Option<Vec<PolicyTopicEvidence>>,
pub help_center_url: Option<String>,
pub missing_certificate: Option<bool>,
pub policy_topic: Option<String>,
}Expand description
Each policy topic entry will represent a violation of a policy topic for a creative, with the policy topic information and optional evidence for the policy violation.
This type is not used in any activity, and only used as part of another schema.
Fields
evidences: Option<Vec<PolicyTopicEvidence>>Pieces of evidence associated with this policy topic entry.
help_center_url: Option<String>URL of the help center article describing this policy topic.
missing_certificate: Option<bool>Whether or not the policy topic is missing a certificate. Some policy topics require a certificate to unblock serving in some regions. For more information about creative certification, refer to: https://support.google.com/authorizedbuyers/answer/7450776
policy_topic: Option<String>Policy topic this entry refers to. For example, “ALCOHOL”, “TRADEMARKS_IN_AD_TEXT”, or “DESTINATION_NOT_WORKING”. The set of possible policy topics is not fixed for a particular API version and may change at any time. Can be used to filter the response of the creatives.list method