pub struct PolicyTopicEvidence {
pub destination_not_crawlable: Option<DestinationNotCrawlableEvidence>,
pub destination_not_working: Option<DestinationNotWorkingEvidence>,
pub destination_url: Option<DestinationUrlEvidence>,
pub domain_call: Option<DomainCallEvidence>,
pub download_size: Option<DownloadSizeEvidence>,
pub http_call: Option<HttpCallEvidence>,
pub http_cookie: Option<HttpCookieEvidence>,
}Expand description
Evidence associated with a policy topic entry.
This type is not used in any activity, and only used as part of another schema.
Fields
destination_not_crawlable: Option<DestinationNotCrawlableEvidence>The creative’s destination URL was not crawlable by Google.
destination_not_working: Option<DestinationNotWorkingEvidence>The creative’s destination URL did not function properly or was incorrectly set up.
destination_url: Option<DestinationUrlEvidence>URL of the actual landing page.
domain_call: Option<DomainCallEvidence>Number of HTTP calls made by the creative, broken down by domain.
download_size: Option<DownloadSizeEvidence>Total download size and URL-level download size breakdown for resources in a creative.
http_call: Option<HttpCallEvidence>HTTP calls made by the creative that resulted in policy violations.
Evidence for HTTP cookie-related policy violations.