RemoveTargetedAppsRequest

Struct RemoveTargetedAppsRequest 

pub struct RemoveTargetedAppsRequest {
    pub app_ids: Option<Vec<String>>,
}
A request to stop targeting the provided apps in a specific pretargeting configuration. The pretargeting configuration itself specifies how these apps are targeted. in PretargetingConfig.appTargeting.mobileAppTargeting.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

app_ids: Option<Vec<String>>

A list of app IDs to stop targeting in the pretargeting configuration. These values will be removed from the list of targeted app IDs in PretargetingConfig.appTargeting.mobileAppTargeting.values.