pub struct StringTargetingDimension {
pub targeting_mode: Option<String>,
pub values: Option<Vec<String>>,
}Expand description
Generic targeting with string values used in app, website and publisher targeting.
This type is not used in any activity, and only used as part of another schema.
Fields
targeting_mode: Option<String>How the items in this list should be targeted.
values: Option<Vec<String>>The values specified.