UserList

Struct UserList 

pub struct UserList {
    pub description: Option<String>,
    pub display_name: Option<String>,
    pub membership_duration_days: Option<i64>,
    pub name: Option<String>,
    pub status: Option<String>,
    pub url_restriction: Option<UrlRestriction>,
}
Represents an Authorized Buyers user list. Authorized Buyers can create/update/list user lists. Once a user list is created in the system, Authorized Buyers can add users to the user list using the bulk uploader API. Alternatively, users can be added by hosting a tag on the advertiser’s page.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

description: Option<String>

The description for the user list.

display_name: Option<String>

Required. Display name of the user list. This must be unique across all user lists for a given account.

membership_duration_days: Option<i64>

Required. The number of days a user’s cookie stays on the user list. The field must be between 0 and 540 inclusive.

name: Option<String>

Output only. Name of the user list that must follow the pattern buyers/{buyer}/userLists/{user_list}, where {buyer} represents the account ID of the buyer who owns the user list. For a bidder accessing user lists on behalf of a child seat buyer, {buyer} represents the account ID of the child seat buyer. {user_list} is an int64 identifier assigned by Google to uniquely identify a user list.

status: Option<String>

Output only. The status of the user list. A new user list starts out as open.

url_restriction: Option<UrlRestriction>

Required. Deprecated. This will be removed in October 2023. For more information, see the release notes: https://developers.google.com/authorized-buyers/apis/relnotes#real-time-bidding-api The URL restriction for the user list.