pub struct WatchCreativesRequest { /* private fields */ }Expand description
A request to receive push notifications when any of the creatives belonging to the bidder changes status.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- creatives watch bidders (request)