pub struct VideoMetadata {
pub duration: Option<Duration>,
pub is_valid_vast: Option<bool>,
pub is_vpaid: Option<bool>,
pub media_files: Option<Vec<MediaFile>>,
pub skip_offset: Option<Duration>,
pub vast_version: Option<String>,
}Expand description
Video metadata for a creative.
This type is not used in any activity, and only used as part of another schema.
Fields
duration: Option<Duration>The duration of the ad. Can be used to filter the response of the creatives.list method.
is_valid_vast: Option<bool>Is this a valid VAST ad? Can be used to filter the response of the creatives.list method.
is_vpaid: Option<bool>Is this a VPAID ad? Can be used to filter the response of the creatives.list method.
media_files: Option<Vec<MediaFile>>The list of all media files declared in the VAST. If there are multiple VASTs in a wrapper chain, this includes the media files from the deepest one in the chain.
skip_offset: Option<Duration>The minimum duration that the user has to watch before being able to skip this ad. If the field is not set, the ad is not skippable. If the field is set, the ad is skippable. Can be used to filter the response of the creatives.list method.
vast_version: Option<String>The maximum VAST version across all wrapped VAST documents. Can be used to filter the response of the creatives.list method.